Installation
============

To install the latest release, type::

    pip install django-db-mutex

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-db-mutex.git
